@@ -35,9 +35,4 @@ echo "IMAGE_URLS=$SAHARA_IMAGE" >> $LOCALCONF_PATH
 
 echo -e '[[post-config|$SAHARA_CONF_FILE]]\n[DEFAULT]\n' >> $LOCALCONF_PATH
 
-
-if [ "$NETWORK" == "nova-network" ]; then
-    echo -e 'heat_enable_wait_condition=false\n' >> $LOCALCONF_PATH
-else
-    echo -e 'min_transient_cluster_active_time=90\n' >> $LOCALCONF_PATH
-fi
+echo -e 'min_transient_cluster_active_time=90\n' >> $LOCALCONF_PATH
